@@ -1,13 +1,13 @@
 import os
 
-_version = "1.0.6"
+_version = "1.0.7"
 
 _pipelist = [
     "data",
     'count',
     'analysis',
     'report',
-    #'clean',
+    'clean',
     #'mkref',
     'run',
     'list',
