@@ -52,16 +52,19 @@ beads_stat = beads_stat.drop(['BARCODE','GN'], axis=1)
 beads_stat = beads_stat.groupby("CELL").agg('sum')
 beads_stat.to_csv(os.path.join(indir,'merge_cell.stat'),sep='\t')
 
-barcodeTranslate['Count'] = barcodeTranslate['CELL'].str.split('_N',expand=True)[1]
-figtable = barcodeTranslate.Count.value_counts()
+barcodeTranslate['frequence'] = barcodeTranslate['CELL'].str.split('_N',expand=True)[1]
+figtable = barcodeTranslate.frequence.value_counts()
 figtable = figtable.reset_index(level=None, drop=False, name=None, inplace=False)
-figtable.columns = ['Num', 'Count']
+figtable['index'] = figtable['index'].astype(int)
+figtable['Count'] = figtable.apply(lambda x: round(x['frequence']/x['index']), axis=1)
+figtable.columns = ['Num', 'frequence','Count']
+figtable['Num'] = figtable['Num'].astype(str)
 cellnum = figtable['Count'].sum()
 figtable['num_count'] = figtable["Num"].map(str) +'  '+figtable["Count"].map(str)
 
 from plotnine import *
 
-p = ggplot(figtable,aes(x='Num',y='Count',fill = 'Num'))+ \
+p = ggplot(figtable,aes(x='Num',y='Count',fill ='Num'))+ \
     geom_bar(stat='identity') + \
     scale_fill_brewer(type="qual", palette="Set2",labels =figtable['num_count']) + \
     xlab('Number of beads per droplet') + \
