@@ -156,7 +156,7 @@ cluster = pd.read_csv(cluster_file)
 df = pd.read_csv(cluster_file)
 df = df.sort_values(by='Cluster')
 df[['Cluster']] = df[['Cluster']].astype('str')    
-fig = px.scatter(df, x=df.UMAP_1, y=df.UMAP_2, color= df['Cluster'], )
+fig = px.scatter(df, x=df.UMAP_1, y=df.UMAP_2, color= df['Cluster'])
 
 config=config
 fig.update_layout(
@@ -171,6 +171,7 @@ fig.update_layout(
     yaxis=dict(gridcolor='lightgray',)
 
     )
+fig.update_traces(marker={'size': 4})
 fig.update_xaxes(zeroline=True, zerolinewidth=1, zerolinecolor='gray')
 fig.update_yaxes(zeroline=True, zerolinewidth=1, zerolinecolor='gray')
 py.offline.plot(fig, filename = outdir+"/04.report/div/cluster.html",auto_open=False,config=config)
@@ -198,6 +199,7 @@ fig.update_layout(
     xaxis=dict(gridcolor='lightgray',),
     yaxis=dict(gridcolor='lightgray',)
     )
+fig.update_traces(marker={'size': 4})
 fig.update_xaxes(zeroline=True, zerolinewidth=1, zerolinecolor='gray')
 fig.update_yaxes(zeroline=True, zerolinewidth=1, zerolinecolor='gray')
 py.offline.plot(fig, filename = outdir+"/04.report/div/cluster_nUMI.html",auto_open=False,config=config)
@@ -211,7 +213,6 @@ fw1 = open(outdir+"/04.report/div/nUMI_chsize.div","w")
 fw1.write(barplot_chsize)
 fw1.close()
 print('''###########################
-
 # 2.2 cluster annotation plot
 ###########################''')
 ####################plot nUMI
@@ -229,6 +230,7 @@ if 'Predicted cell type' in df.columns:
     xaxis=dict(gridcolor='lightgray',),
     yaxis=dict(gridcolor='lightgray',)
     )
+    fig.update_traces(marker={'size': 4})
     fig.update_xaxes(zeroline=True, zerolinewidth=1, zerolinecolor='gray')
     fig.update_yaxes(zeroline=True, zerolinewidth=1, zerolinecolor='gray')
     py.offline.plot(fig, filename = outdir+"/04.report/div/anno.html",auto_open=False,config=config)
@@ -242,7 +244,6 @@ if 'Predicted cell type' in df.columns:
     fw1.write(barplot_chsize)
     fw1.close()
 print('''###########################
-
 # 2.3 saturation plot
 ###########################''')
 ####################plot nUMI
